# Authors of BioSimulator Processes:

The maintainers of the biosimulator-processes project are:

* Alexander Patrie (@AlexPatrie)

The maintainers of the Process-Bigraph project are:

* Ryan Spangler (@prismofeverything)
* Eran Agmon  (@eagmon)


